[![Documentation Status](https://readthedocs.org/projects/equinox-server/badge/?version=latest)](https://equinox-server.readthedocs.io/en/latest/?badge=latest)

# Equinox Overview
![Equinox Logo](/docs/source/equinox-logo.png) Equinox is an open source platform that supports the holistic risk management and reporting of major sustainable finance projects (the financing of projects with material physical footprint) such as project finance.

## The Challenge of Project Finance and Sustainability
Sustainability (understood both in environmental and social terms) is a serious and ongoing issue that affects all economies. Developing tools and methodologies that improve the ability of all stakeholders to assess and report risks is thus an important objective

## What exactly is Equinox?
Equinox is a *database and a web application frontend* that works together with a tailored data schema to provide a flexible and powerful Sustainable Finance platform adhering to many regulatory and ESG initiatives and recommendations. 

Running the application creates a local *server* that can then be accessed via any regular web browser. For easy installation and testing the current release uses an sqlite database instead of a production database.

## Functionality

The initial functionality of Equinox focuses on integrating the following concepts:

* The European Banking Authority's Criteria for Credit Risk Assessment of Project Finance under the Standardized approach for Specialized Lending 
* The PCAF coalition's approach to accounting and reporting project finance GHG emissions
* Equator Principles for Project Finance
* GHG Accounting Protocol for Projects


## Credits
* Django
* Jazzmin
* European Banking Authority
* Partnership for Carbon Accounting Financials  
* Equator Principles
